@@ -30,6 +30,7 @@ from weaverbird.steps import (
     RollupStep,
     SelectStep,
     SortStep,
+    SplitStep,
     StatisticsStep,
     SubstringStep,
     TextStep,
@@ -38,6 +39,7 @@ from weaverbird.steps import (
     UniqueGroupsStep,
     UnpivotStep,
     UppercaseStep,
+    WaterfallStep,
 )
 
 PipelineStep = Union[
@@ -76,7 +78,9 @@ PipelineStep = Union[
     RollupStep,
     UniqueGroupsStep,
     UppercaseStep,
+    SplitStep,
     SubstringStep,
+    WaterfallStep,
 ]
 
 
